# -*- encoding:utf-8 -*-
import json

from flask_app.general.post_processing import inner_post_processing, get_nested
from flask_app.general.纯技术参数要求提取 import extract_matching_keys


def outer_post_processing(combined_data, includes,good_list):
    # print(good_list)
    """
    外层处理函数，调用内层 post_processing 处理 '基础信息'，并构建 processed_data。
    额外提取 '采购要求' 下的 '技术要求' 内容。

    参数:
        combined_data (dict): 原始合并数据。
        includes (list): 需要包含的键列表。

    返回:
        tuple: (processed_data, extracted_info, procurement_reqs)
    """
    # 初始化结果字典，预设'其他'分类为空字典
    processed_data = {"其他": {}}

    # 初始化提取的信息字典
    extracted_info = {}

    # 初始化采购要求的技术要求
    procurement_reqs = ""

    # 检查 '基础信息' 是否在 includes 中
    if "基础信息" in includes:
        base_info = combined_data.get("基础信息", {})
        # 调用内层 post_processing 处理 '基础信息'
        extracted_info = inner_post_processing(base_info)
        # 将 '基础信息' 保留在处理后的数据中
        processed_data["基础信息"] = base_info
        # 提取 '采购要求' 下的 '采购需求'
        tech_requirements = get_nested(base_info, ["采购要求", "采购需求"], {})
        if tech_requirements:
            procurement_reqs = extract_matching_keys(tech_requirements,good_list)
        else:
            # 如果 '技术要求' 不存在或为空，可以根据需要设置默认值
            procurement_reqs = "未提供"

    # 遍历原始字典的每一个键值对
    for key, value in combined_data.items():
        if key in includes:
            if key == "基础信息":
                # 已经处理 '基础信息'，无需再次添加
                continue
            else:
                # 直接保留包含在 includes 列表中的键值对
                processed_data[key] = value
        else:
            # 将不在 includes 列表中的键值对加入到 '其他' 分类中
            processed_data["其他"][key] = value

    # 如果 '其他' 分类没有任何内容，可以选择删除这个键
    if not processed_data["其他"]:
        del processed_data["其他"]

    return processed_data, extracted_info, procurement_reqs

data={
    "基础信息": {
        "招标人/代理信息": {
            "招标人": "广水市公安局",
            "招标人联系方式": {
                "名称": "广水市公安局",
                "联系电话": "0722-6248000",
                "地址": "广水市应山办事处应十大道189号"
            },
            "招标代理机构": "湖北楚振捷工程项目管理有限公司",
            "招标代理机构联系方式": {
                "名称": "湖北楚振捷工程项目管理有限公司",
                "联系电话": "0722-6256088",
                "地址": "广水市永阳一路41号"
            },
            "项目联系方式": {
                "名称": "吴凡",
                "联系电话": "18871130808"
            }
        },
        "项目信息": {
            "项目名称": "广水市公安局视频会议高清化改造项目",
            "项目编号": "HBCZJ-2021-CS12",
            "项目概况": "广水市公安局视频会议高清化改造项目",
            "项目基本情况": {
                "项目编号": "HBCZJ-2021-CS12",
                "采购计划备案号": "2021-04-000399",
                "项目名称": "广水市公安局视频会议高清化改造项目",
                "采购方式": "竞争性磋商",
                "预算金额": "192万元",
                "最高限价": "192万元",
                "采购需求": {
                    "项目概况及内容": "广水市公安局视频会议高清化改造项目。",
                    "招标范围": "广水市公安局视频会议高清化改造项目，具体内容见磋商文件第三章。",
                    "项目地点": "具体以合同约定为准。"
                },
                "合同履行期限": "以合同签订为准。",
                "本项目（是/否）接受联合体投标": "否",
                "是否可采购进口产品": "否"
            },
            "招标控制价": "192万元",
            "投标竞争下浮率": "未知",
            "是否允许分包": "未知",
            "是否接受联合体投标": "否"
        },
        "采购要求": {
            "采购需求": {
                "显示系统": {
                    "交换机-1":["111"],
                    "交换机-2":["222"],
                    "LED全彩显示屏": [
                        "1、显示尺寸：6m±0.3（W）× 1.5m±0.2(H),单屏分辨率≥3744 × 1040；",
                        "2 、像素间距≤1.53mm；",
                        "3 、亮度≥450nits， 色温： 3000-15000K 可调， 对比度： 5000:1；",
                        "4 、峰值功耗≤440W， 平均功耗≤146W， 带有智能（黑屏） 节电功 能， 开启智能节电功能比没开启节能 40%以上；",
                        "5 、水平可视角度≥160 ° , 垂直可视角度≥140 ° ;",
                        "6 、亮度均匀性≥97%， 刷新率≥3840 Hz ， 发光点中心距偏差＜3%；",
                        "7 、色域覆盖率≥100%， 低亮高灰： 100%亮度时， 16 bits 灰度，20% 亮度时， 12bits 灰度；",
                        "8 、铝底壳材质， 无风扇散热结构；",
                        "9 、模组电源接口采用4P 接插头， 免工具维护， 同时有防呆设计， 预防接错电源线短路而导致的烧毁模组行为，采用集成 HUB 接收卡 控制， 支持通讯状态监控；",
                        "10 、冗余备份， 支持双电网供电， 当其中一路交流电网跳闸后， 另 外一路电网继续供电， 实现不间断供电， 支持热备份， 当其中一块 电源失效后， 另一块电源继续工作， 从而实现不间断供电；",
                        "11 、屏体发光模组采用 4.5 VDC 的安全电压供电；",
                        "12 、彩色信号处理位数≥16bit；",
                        "13 、具备故障自诊及排查功能；",
                        "14 、 图像有降噪 、增强 、运动补偿 、色坐标变换处理 、钝 化处理无 几何失真和线性失真现象 、消除鬼影拖尾， 无“毛毛虫 ”“鬼影 ” 跟随现象；",
                        "15 、防护等级符合 IP6X， 显示屏具有防潮 、防尘 、防腐蚀 、防电磁 干扰 、防静电等功能， 并具有过流、短路 、过压 、欠压保护等功能；",
                        "16 、工作噪音声压等级一米处≤7.8 dB (A),盐雾符合 10 级要求， PCB 阻燃等级达到 UL 94 V-0 级要求， 通过 9 级烈度地震模拟实验。"
                    ],
                    "控制盒及电源": [
                        "高清发送盒 2 台 、接收卡 27 张 、 电源 26 台。"
                    ],
                    "大屏播控系统": [
                        "1、具有多用户多权限管理功能，支持多用户同时登录客户端，每个用户根据自身不同权限管理显示屏；",
                        "2 、系统对输入信号源进行预监视， 实现在播控前预先查看的功能。"
                    ],
                    "配电柜（含PLC）": [
                        "1 、10 KW 容量，施耐德元器件，含 PLC 控制系统，可实时获取屏幕背部烟雾及温度数据， 可执行远程开关机操作； 数字量 输入： 12 路 24 V DC 输入；数字量输出： 10 路继电输出；模拟量输 入：4 个电压 输入，4 个电流输入；通讯口： 1 个 RS232,2 个 RS485， 1 个以太网； 程序容量： 256K 片内 Flash 内存； 功能： 远程监控 、 电话监视 、温 度监控 、消防监控；",
                        "2、本配电柜具备过压、过流、欠压、短路、断路以及漏电保护措施。"
                    ],
                    "钢结构底座及铝型材支架": [
                        "1 、主体钢架结构及定制型材；",
                        "2 、确保楼层承受力许可,按需加固楼层地面；",
                        "3 、钢结构。"
                    ],
                    "电缆及信号线缆": [
                        "1 、配套所需控制网线 、高清视频线缆 、 电源线缆等适配。"
                    ],
                    "控制终端": [
                        "1 、处理器： 八核心 16 线程；",
                        "2 、显卡： 8G/DDR6/PCI Express 4.0 16X；",
                        "3 、 内存： ≥8G DDR4 内存；",
                        "4 、硬盘： SSD 固态硬盘(容量≥480G)；",
                        "5 、接口： 音频/网络/HDMI 接口/9 针串口；",
                        "6 、显示器： 21.5 英寸。"
                    ],
                    "50寸液晶电视机": [
                        "1 、屏幕尺寸： 50 英寸；",
                        "2 、背光类型： LED；",
                        "3 、屏幕分辨率： 超高清 4K （3840 ×2 160）；",
                        "4 、支持 HDR 显示；",
                        "5 、接口： USB2.0 ×2 、HDMI2.0 ×3；",
                        "6 、 网络连接方式： 无线/网线。"
                    ],
                    "50寸电视机地面推车": [
                        "1 、全钢结构， 满足 50 寸显示屏承重安装要求；",
                        "2 、承载： 50Kg；",
                        "3 、高度： 650mm；",
                        "4 、可以调节观看角度。"
                    ],
                    "高清监视器": [
                        "1 、27 寸全屏高清监视器；",
                        "2 、 IPS 技术炫彩硬屏， 4K 高清分辨率；",
                        "3 、 内置音箱；",
                        "4 、亮度： 350cd/m2；",
                        "5 、接口： DP × 1， HDMI ×2， USB ×2， 音频/耳机 × 1。"
                    ]
                },
                "摄像系统": {
                    "交换xx":["111111"],
                    "高清摄像机": [
                        "1 、成像器件： 1/2.8 Exmor CMOS；",
                        "2 、镜头： 30 倍光学（f=4.3mm to 129mm ）；",
                        "3 、水平视角： 63.7 ° ;",
                        "4、视频输出格式：1080P/60，1 080P/50，1080P/30，1080P/25，1080i/60， 720p/60；",
                        "5 、视频输出： 3G-SDI， HDMI， CVBS,IP （可同步输出 ）；",
                        "6 、真双输出： IP 和 SDI 视频格式可以独立设置；",
                        "7 、控制方式： RS232 / RS422 / RS485， IP/Onvif/Visca-over-IP， IP 控制软件， 红外遥控器；",
                        "8 、IP 最高 1080p60， 支持 H.264/H.265/MJPEG；",
                        "9 、支持 Tally 灯；",
                        "10 、支持独立 PoE+（IEEE 802.3 at） 和 DC 12V 电源；",
                        "11 、扩展存储： Micro SD,最高支持 128GB。"
                    ],
                    "摄像机三角架": [
                        "1 、铝合金材质， 承重 2-10Kg；",
                        "2 、满足高清摄像机承重 、尺寸要求。"
                    ],
                    "摄像机壁装架": [
                        "1 、钣金 2.0mm 优质冷轧钢板；",
                        "2 、满足高清摄像机壁挂安装承重 、尺寸要求；",
                        "3 、具有放置摄像机电源空间。"
                    ],
                    "摄像机控制键盘": [
                        "1 、支持串行 RS232/RS422 和 IP 混合控制， 允许在一个控制器上使用 RS232/RS422/IP 控制单个系统中的摄像机；",
                        "2 、支持 2 组 RS422 串口 VISCA 协议菊花链控制 2x7 台摄像机；",
                        "3、通过手柄或单独的 Seesaw 控制杆控制变焦，通过专用旋钮及按钮， 可直接设置摄像机的光圈 、快门 、增益 、白平衡 、自动曝光等级等参数， 无需通过菜单设置；",
                        "4 、使用 IP 控制，控制器可自动搜索系统中的 IP 摄像机， 快速分配 摄像机 IP 地址 。支持 Onvif 、CGI 、VISCA over IP；",
                        "5 、单个网络上不限制控制器， 控制 255 台 IP 摄像机；",
                        "6、多达 256 个预置位，带有图像参数记忆功能及 8 条 轨迹记忆存储， 方便快速调用摄像机的运动 （需摄像机支持 ）；",
                        "7 、6 个可选 ASSIGN 功能键， 可以为 ASSIGN 按钮分配附加功能；",
                        "8 、多色按键/旋钮照明指示摄像机当前状态；",
                        "9 、独立双电源供电： DC 12V ,POE。"
                    ]
                },
                "视频处理系统": {
                    "交换xx":["xxxx"],
                    "高清视频拼控矩阵（16*16）": [
                        "1 、8U 切换主箱体， 支持输入 13 槽， 输出 4.5 槽， 支持 8 路高分采集， 支持冗余电源， 标配 1 个电源模块； 本项目配置输入接 口 16 路和 1 张字幕卡， 输出接口 16 路；",
                        "2 、设备应为纯硬件 FPGA 架构， CrossPoint 全总线交换技术， 背板 等效带宽；",
                        "3 、单张板卡支持 4 通道输入或输出， 紧凑型机箱,模拟视频单板卡 支持 16 路同时输入， 单卡支持 2 种信号源任意组合；",
                        "4、输入输出板卡可热插拔，输入板卡热插拔恢复时间 ＜2s，输出板 卡热插拔恢复时间＜8s；",
                        "5 、开机时间≤10s， 启动电源至输出最总画面的时间间隔；",
                        "6 、平均故障时间间隔 （ MTBF ） 不小于 96000 小时， 保证设备能够 稳定运行；",
                        "7 、最大单机背板信号处理带宽不小于 720Gbps；",
                        "8、对各个输入通道采用纯硬件处理技术，采用独享带宽方式为每个 输入通道分配带宽， 切换过程中对其他信号无影响， 实现了对输入 通道的实时处理；",
                        "9、支持集中采集 DVI、VGA、CVBS、HDBaseT、HDMI、SDI、YPbPr 、 光纤等 2K 信号，Dual-link DVI、HDMI 1.4、DisplayPort 等 4K 信号；",
                        "10 、支持 DVI 、HDBaseT 、HDMI 、SDI 、光纤 、CVBS 、Ypbp r 等常 见的 2K 信号输出， Dual-link DVI 、HDMI 1.4 等 4K 信号输出；",
                        "11、设备可实现任意一路画面的任意比例缩放、漫游、 跨屏 、叠加、 开窗；",
                        "12 、设备支持图像无缝实时切换功能， 无缝切换时间＜20 ms ；",
                        "13 、支持场景保存及快速调用， 支持场景轮巡， 适应于不同的应用 场景；",
                        "14 、支持信号源预监功能， 支持浏览所有输入信号源的实时预览画 面；",
                        "15 、支持大屏图像回显， 可显示整面拼接墙的显示图像；",
                        "16 、支持设置拼接屏的拼缝补偿， 可精确到 1 个像素；",
                        "17 、支持 RRTA 分辨率实时全兼容技术， 单台 设备应支持同时控制 4 组不同分辨率的大屏幕显示；",
                        "18 、设备具备静态底图功能， 设备支持超大分辨率底图显示， 横纵 分辨率最大 65535 像素。"
                    ],
                    "分量信号接口器": [
                        "用于现有视频会议专业对接高清矩阵接口器"
                    ],
                    "高清四画面分割器": [
                        "1、画面预览使用， 具有画中画 、独立单画面放大功能。"
                    ]
                },
                "发言系统": {
                    "数字会议发言主机": [
                        "1 、标准挂载单元数量： 4 路总线接口， 单路可连接 32 个 ， 最多系统可挂载 128 个会议单元， 且最远线路长度可高达 100 米；",
                        "2、主机面板彩屏显示系统菜单，通过设置可设 定 1/2/4/6 发言数量；",
                        "3 、支持先入先出模式， 后入后出模式， 限制模式， 电脑/主席允许 模式， 自由讨论模式；",
                        "4 、可直接控制最多三个摄像球， 完成视频会议功能；",
                        "5、多种输入输出接口主输入、卡座输入和前置输出、辅助输出及录 音输出接口；",
                        "6 、带有 RS 232 视频控制输出 口， 可以直接输出派尔高-P， 派尔高 -D， VISCA 控制协议， 控制最大 3 个摄像机， 完成摄像自动跟踪；",
                        "7 、 内置 4 切 1 视频切换器， 用于摄像机的视频 接连；",
                        "8 、可以响应处理话筒的会议中服务的请求；",
                        "9 、 内置签到表决功能， 可以配合话筒进行签到表决；",
                        "10 、 内置 DSP 自适应音频处理器,可以最大可能的抑制声回输。"
                    ],
                    "方形短杆代表话筒": [
                        "1 、超大静音开关设计；",
                        "2 、会议操作系统,全新的触摸操控技术， 2.8 英寸的彩色触摸屏幕；",
                        "3 、超短全金属短咪杆设计；",
                        "4 、高灵敏度咪芯设计,拾音距离≥80 cm ；",
                        "5 、红色雾面指示灯设计， 指示发言状态；",
                        "6 、支持视像跟踪；",
                        "7、配合主机， 可以实现先入先出，后入后出， 限制模式，主席允许模式， 自由讨论模式；",
                        "8、话筒的身份可以自行设定，可以通过主机设置改变话筒身份，在 代表， 主席， VIP 自由切换， 让使用更灵活多样， 满足 高端需求；",
                        "9 、长距离传输对音质不会有影响； 具备超强的抗手机 RF 干扰性。"
                    ],
                    "专用连接线缆": [
                        "1 、主机与话筒专用连接线缆， 长度≥30m。"
                    ],
                    "手持无线话筒": [
                        "1 、含一台接收机， 两个无线手持话筒发射器；",
                        "2 、频率响应： 50Hz-18KHz；",
                        "3 、有效使用距离≥100 米；",
                        "4 、信噪比≥105dB(1KHz-A)；",
                        "5 、灵敏度： -105dBm(12dB S/N AD)。"
                    ]
                },
                "视频会议系统": {
                    "多点控制器": [
                        "1 、遵循 H.323 、H.320 、SIP 标准协议；",
                        "2 、支持 H.265， H.264 HP， H.264 编解码标 准。 3 、支持不低于 25 分屏高清多画面; 4 、最大线路速率： 8M； 5、视频抗丢包能力：支持高至 60%丢包率情况下 ， 图像流畅无马赛 克；音频抗 IP 网络丢包能力：支持高至 75%丢包 率情况下，声音清 晰流畅； 会议抗 IP 网络丢包能力：支持高至 70%丢包率情况下，会 议仍可正常召开。 以上 5 项参数需提供第三方检测机构检验 报告。"
                    ],
                    "多串口控制服务器": [
                        "1 、具有高速数据处理能力， 内嵌高速嵌入式 CPU ；",
                        "2 、提供 16 路一控多 、多控一；",
                        "3 、具有多种转发机制， 支持 IP 、串口间双向转发机制；",
                        "4、控制会议矩阵、会议摄像机外围设备串口设备，实现对会议系统 设备的控制；"
                    ],
                    "综合会议管理调度平台": [
                        "1、含硬件终端和视频会议专用软件，用于控制会 议、矩阵、会议摄像机， 实现与省厅 、 随州市综合会议管理调度平台对接 、融合， 互 联互通；",
                        "2 、统一调度管理平台， 根据业务需要， 可互为控制 、互为 备份；",
                        "3、可以与原有的主控平台互为操作、实现控制备份，保证会议正常 召开， 需在设计方案中详细阐明如何实现；",
                        "4、实现对会议设备的整合控制，采用一键拖拉式操作，软件界面友 好 、操作管理简易 、直观；",
                        "5 、可在综合会议管理平台实现四画面预览各分会场及中心视频信 号；",
                        "6 、提供软件著作权证书。"
                    ],
                    "高清会议终端(主会场)": [
                        "1 、体系标准： ITU-T H.323 、H.320 、IETF SIP/专有平台协议；",
                        "2 、 网 络 传 输 协 议： TCP/IP， UDP， RTP/RTC P/ RTSP， HTTP， DHCP/PPPOE/ NAT， IGMP；",
                        "3 、视频编解码协议： H.265， H.264 HP， H.264 、H.2 63 、MPEG-4；",
                        "4 、音频编解码协议： G.711a/G.711u 、G.722/G.723/G.7 19/AAC-LC；",
                        "5 、视频码率： 128Kbps～ 16Mbps， 支持 16M（ E1*8 ）；",
                        "6 、音频码率： 24Kbps～384Kbps；",
                        "7 、 内 容 分 辨 率 ： 典 型 : 动 态 (HDMI/VGA) 1 080P60 ， 静 态 (VGA)1600*1200@60 Up to 60fps；",
                        "8 、音频指标： AEC/ANS/AGC 等；",
                        "9 、音频特性： 唇音同步， 静音与哑音控制；",
                        "10 、接口指标： 遥控接口 NEC 码制标准红外接口,支持遥控器直接 控制终端；",
                        "11 、通信控制接 口： RJ45 × 2(RS232 x 1， RS48 5 x1)， 摄像机控制 RJ45-232 接口通用路由器己置线;另预留 RS232 x 2；",
                        "12 、 网 络 接 口 ： LAN ， RJ45 x 4 ， E1 (4x E1) ， CC4/miniBNC x 810/100/1000Mbps2/4/6/8Mbps；",
                        "13、视频输出接口：3G-SDIx1、HDMIx1，DVI-Ix1，CVBSx1，VGAx1， DVI -I 可以配置选择 DVI / HDMI / VGA / YPrPb 任何一种接口模式输入 图像， 高标 、清接口可同时输出；",
                        "14、音频接口：音频输出输出采用“凤凰接口 ”， LINE IN, MAIN (3pin) × 1，XLR IN (3pin) × 1，XLR 用于 MIC 输入时支持，+48V 幻象供 电， LINE OUT,MAIN (3pin) × 1；",
                        "15 、遵循 H.323 、H.320 、SIP 协议标准；",
                        "16 、视频抗丢包能力： 支持高至 60%丢包率情况下， 图像流畅 、无 卡顿、无马赛克；音频抗 IP 网络丢包能力：支 持高至 75%丢包率情 况下，声音清晰流畅； 会议抗 IP 网络丢包能力：支持高至 70%丢包 率情况下， 会议可正常召开。"
                    ],
                    "高清会议终端(分会场)": [
                        "内置 1080P 高清摄像机， 12 倍光 学变焦，72 度广角镜头，DVI-I 接 口辅流输入，2 路 1080P@30fps 高清视频， 6M 速率，双 HDMI 接口 输出，双屏双显、单屏双显、单屏三显、单屏四显 ,含终端控制软件。"
                    ],
                    "65寸电视机移动推车(9楼)": [
                        "1 、全钢结构， 满足 70 寸电视承重安装要求；",
                        "2 、承载： 200Kg；",
                        "3 、轮子带自锁刹车功能。"
                    ],
                    "65寸液晶电视机(分会场)": [
                        "1 、屏幕尺寸： 65 英寸； 含挂架及安装；",
                        "2 、背光类型： LED；",
                        "3 、屏幕分辨率： 超高清 4K （3840 ×2 160）；",
                        "4 、支持 HDR 显示；",
                        "5 、CPU： Cortex A55 四核；",
                        "6 、接口： USB2.0 ×2 、HDMI2.0 ×2；",
                        "7 、 网络连接方式： 无线/网线。"
                    ],
                    "控制平板及软件": [
                        "10.2 寸无线触摸屏， 含控制软件， 实现远程一键式控制 、视频 会议 调度。"
                    ],
                    "鹅颈话筒": [
                        "1 、采样率： 48kHz；",
                        "2 、频响： 20Hz – 20kHz；",
                        "3 、灵敏度： 38 ±2dB；",
                        "4 、拾音距离： 20-50CM;含接头 、线缆， 线缆 长度≥3.5m；",
                        "5 、支持终端远程供电， 无需外接电源。"
                    ]
                },
                "辅助系统": {
                    "时序电源": [
                        "1 、具有 12 路 1KW 电源；",
                        "2 、具有电压表指示， 支持串口控制；",
                        "3 、采用触点闭合控制功能；",
                        "4 、具有过压 、过流保护。"
                    ],
                    "多媒体地插盒": [
                        "1 、具有至少 1 路 HDMI 、 1 路电源 、2 路网络接口模块；",
                        "2 、采用优质接插件。"
                    ],
                    "线材辅料": [
                        "1、采用专用线材 、材料 、接口 、各种辅料等。"
                    ],
                    "墙体拆除及修复": [
                        "对大屏安装区域墙体 、天花进行拆除及修复。"
                    ]
                }
            },
            "技术要求": "未知",
            "服务要求": "四 、其他要求<br>1 、售后服务要求：<br>1.1 、安装调试与人员培训， 中标人应及时安装调试设备， 安装调试期间采 购人的使用人员协助配合；安装调试完毕，中标人需组织采购人使用人员进行使 用及日常维护等的培训。<br>1.2 、免费质保期一年， 质保期从采购人签订验收合格报告之日开始计算， 免费质保期内中标人负责所有因设备质量问题而产生的费用， 所有服 务免费。<br>1.3 、投标人需承诺在保修期内， 向用户提供 7×24 小时技术支持与上门服 务。对系统故障的响应时间不超过 2 小时， 到达现场时 间不超过 24 小时，在 48 个小时内排除故障 。如果发生硬件故障， 在 4 8 小时后仍无法排除的， 投标人需 承诺提供性能档次不低于故障设备的备用设备供采购人使用， 直至故障设备修 复。<br>1.4 、保修期外要求： 中标人应提供长期技术支持的措施和质保期满后的服 务计划。",
            "商务要求": "2 、到货要求及交货地点：<br>2.1 、交货地点： 采购人指定地点。<br>2.2 、交货期： 以合同签订时间为准交付正常使用（含安装 、调试） 。<br>2.3 、本项目为“交钥匙 ”工程， 投标人必须完成本工程项目所有的货物采 购 、运输 、安装 、调试 、验收及服务等全部工 作。<br>3 、付款方式： 以合同签订为准。",
            "其他要求": "注： 1 、广水市公安局高清视频会议系统必须与随州市公安局高清视频会议系统无缝对接互联互通；<br>2 、本项目为交钥匙工程。"
        },
        "关键时间/内容": {
            "投标文件递交截止日期": "2021年 6月 18日 15点 00分（北京时间）",
            "投标文件递交地点": "广水市公共资源交易中心五楼 501号开标室",
            "开标时间": "2021年 6月 18日 15点 00分（北京时间）",
            "开标地点": "广水市公共资源交易中心五楼 501号开标室",
            "澄清招标文件的截止时间": "提疑截止时间：同采购文件获取截止时间(如有)",
            "投标有效期": "90日历天",
            "信息公示媒介": "中国湖北政府采购网：http://www.ccgp-hubei.gov.cn, 中国广水网：http://www.zggsw.gov.cn/"
        },
        "保证金相关": {
            "履约保证金": "不提交",
            "退还投标保证金": "/",
            "投标保证金": "不提交",
            "质量保证金": "未知"
        },
        "其他信息": {
            "重新招标、不再招标和终止招标": "未知",
            "投标费用承担": "供应商应承担所有与准备和参加磋商有关的费用，不论磋商的结果如何，采购人和采购代理机构均无义务和责任承担这些费用。",
            "招标代理服务费": {
                "支付标准": "根据国家发展与改革委员会办公厅发改办价格【2003】857 号文的规定，经协商由成交供应商按国家发展和改革委员发改价格【2011】534号文规定货物类取费标准向采购代理机构支付招标代理服务费（包含“招标代理费、评标会务费、评标费”），如本项目各包服务费不足叁仟元则供应商按叁仟元支付服务费。",
                "支付方式": "递交方式：成交服务费由成交供应商在领取成交通知书的同时向代理机构支付，可使用现金或电汇办理，汇款账户信息如下：",
                "账户信息": {
                    "账户名": "湖北楚振捷工程项目管理有限公司",
                    "账户号码": "580742561314",
                    "开户银行": "中国银行股份有限公司广水支行营业部"
                }
            },
            "是否退还投标文件": "否",
            "偏离": {
                "允许偏离的条款": "非★号条款",
                "不允许偏离的条款": "★号条款",
                "允许的负偏离项数及范围": "未知",
                "偏离说明表的位置": "第六章响应文件格式中的采购需求响应、偏离说明表/导读表"
            },
            "投标预备会": "不召开",
            "踏勘现场": "不组织"
        }
    }
}
includes = ["基础信息", "资格审查", "商务评分", "技术评分", "无效标与废标项", "投标文件要求", "开评定标流程"]
good_list=[         "交换机",
                    "交换xx",
                    "LED全彩显示屏",
                    "控制盒及电源",
                    "大屏播控系统",
                    "配电柜（含PLC）",
                    "钢结构底座及铝型材支架",
                    "电缆及信号线缆",
                    "控制终端",
                    "50寸液晶电视机",
                    "50寸电视机地面推车",
                    "高清监视器",
                    "高清摄像机",
                    "摄像机三角架",
                    "摄像机壁装架",
                    "摄像机控制键盘",
                    "高清视频拼控矩阵（16*16）",
                    "分量信号接口器",
                    "高清四画面分割器",
                    "数字会议发言主机",
                    "方形短杆代表话筒",
                    "专用连接线缆",
                    "手持无线话筒",
                    "多点控制器",
                    "多串口控制服务器",
                    "综合会议管理调度平台",
                    "高清会议终端(主会场)",
                    "高清会议终端(分会场)",
                    "65寸电视机移动推车(9楼)",
                    "65寸液晶电视机(分会场)",
                    "控制平板及软件",
                    "鹅颈话筒",
                    "时序电源",
                    "多媒体地插盒",
                    "线材辅料",
                    "墙体拆除及修复"
                ]

final_result, extracted_info, procurement_reqs=outer_post_processing(data,includes,good_list)
print(json.dumps(procurement_reqs,ensure_ascii=False,indent=4))
# print(json.dumps(final_result,ensure_ascii=False,indent=4))